@@ -1,3 +1,5 @@
+from datetime import datetime
+from typing import Dict, Optional
 import pandas as pd
 from pint_pandas import PintArray
 
@@ -9,7 +11,16 @@ def _quantify_series(series, unit):
 
 
 class Dataset:
-    def __init__(self, df, identifier, units=None, metadata=None):
+    df: pd.DataFrame
+    identifier: str
+    modified_at: datetime
+    units: Optional[Dict[str, str]]
+    metadata: Optional[Dict]
+
+    def __init__(
+        self, df: pd.DataFrame, identifier: str, modified_at: datetime, units: Dict[str, str] = None,
+        metadata: Dict = None
+    ):
         """
         Create a dataset from a Pandas DataFrame, an identifier and optional metadata.
 
@@ -39,12 +50,13 @@ class Dataset:
         self.identifier = identifier
         self.units = units
         self.metadata = metadata
+        self.modified_at = modified_at
 
     def copy(self):
         return Dataset(self.df, self.identifier, units=self.units, metadata=self.metadata)
 
     @property
-    def dvc_metadata(self):
+    def dvc_metadata(self) -> Optional[Dict]:
         """
         Return the metadata as it should be stored in the .dvc file.
 
@@ -59,7 +71,7 @@ class Dataset:
             metadata['units'] = self.units
         return metadata
 
-    def equals(self, other):
+    def equals(self, other: pd.DataFrame) -> bool:
         compare_attrs = ('identifier', 'units', 'metadata')
         return self.df.equals(other.df) and all(getattr(self, a) == getattr(other, a) for a in compare_attrs)
 
